@@ -19,6 +19,7 @@ load_dotenv(find_dotenv(".env"))
 builtins.print = functools.partial(print, flush=True)
 
 from toolchest_client.api.auth import get_key, set_key
-from toolchest_client.api.exceptions import ToolchestException, DataLimitError, ToolchestJobError
+from toolchest_client.api.download import download
+from toolchest_client.api.exceptions import ToolchestException, DataLimitError, ToolchestJobError, ToolchestDownloadError
 from toolchest_client.api.query import Query
 from .tools.api import bowtie2, cellranger_mkfastq, kraken2, megahit, shi7, shogun_align, shogun_filter, STAR, test, unicycler
