@@ -21,7 +21,7 @@ class Shi7(Tool):
             output_path=output_path,
             inputs=inputs,
             min_inputs=1,
-            max_inputs=10,  # artificially constrained at 10 for now
+            max_inputs=None,  # note: no limit is set on the # of inputs
             parallel_enabled=False,
             group_paired_ends=True,
             max_input_bytes_per_file=5 * 1024 * 1024 * 1024,
