@@ -9,7 +9,7 @@ the STAR function called by the user, which is given in all caps
 to be in line with the command-line argument.
 """
 from . import Tool
-from toolchest_client.files import merge_sam_files
+from toolchest_client.files import merge_sam_files, OutputType
 
 
 class STARInstance(Tool):
@@ -17,7 +17,7 @@ class STARInstance(Tool):
     The STAR implementation of the Tool class.
     """
     def __init__(self, tool_args, output_name, inputs, input_prefix_mapping,
-                 output_path, database_name, database_version):
+                 output_path, database_name, database_version, parallelize):
         super().__init__(
             tool_name="STAR",
             tool_version="2.7.9a",
@@ -30,8 +30,11 @@ class STARInstance(Tool):
             max_inputs=2,
             database_name=database_name,
             database_version=database_version,
-            parallel_enabled=True,
-            max_input_bytes_per_node=4.5 * 1024 * 1024 * 1024,
+            parallel_enabled=True if parallelize else False,
+            max_input_bytes_per_file=128 * 1024 * 1024 * 1024,
+            max_input_bytes_per_file_parallel=4.5 * 1024 * 1024 * 1024,
+            output_type=OutputType.SAM_FILE if parallelize else OutputType.GZ_TAR,
+            output_is_directory=not parallelize,
         )
 
     def _merge_outputs(self, output_file_paths):
