@@ -4,6 +4,8 @@ toolchest_client.tools.unicycler
 
 This is the Unicycler implementation of the Tool class.
 """
+from toolchest_client.files import OutputType
+
 from . import Tool
 
 
@@ -23,4 +25,8 @@ class Unicycler(Tool):
             input_prefix_mapping=input_prefix_mapping,
             min_inputs=1,
             max_inputs=3,
+            parallel_enabled=False,
+            output_type=OutputType.GZ_TAR,
+            output_is_directory=True,
+            output_names=["assembly.fasta", "unicycler.log"],
         )
